<?php
$servername = "localhost"; 
$username = "*"; 
$password = "*"; 
$dbname = "*"; 

$conn = new mysqli($servername, $username, $password, $dbname);

if ($conn->connect_error) {
    die("Verbindung fehlgeschlagen: " . $conn->connect_error);
}

$stats = [];
$queries = [
    "SELECT COUNT(*) AS permanent_banns FROM ban WHERE until IS NULL" => "Permanent gebannte Spieler",
    "SELECT COUNT(*) AS total_banns FROM ban" => "Gebannte Spieler (AllTime)",
    "SELECT COUNT(*) AS chat_log FROM log WHERE importance = '98'" => "Anzahl der Chatnachrichten",
    "SELECT COUNT(*) AS cmd_log FROM log WHERE importance = '99'" => "Anzahl der Commands",
    "SELECT COUNT(*) AS achievements FROM achievements WHERE done = '1'" => "Erreichte Achievements",
    "SELECT COUNT(*) AS block_add FROM baulog WHERE removed = '0'" => "Bereits platzierte Blöcke",
    "SELECT COUNT(*) AS block_remove FROM baulog WHERE removed = '1'" => "Bereits abgebaute Blöcke",
    "SELECT COUNT(*) AS total_players FROM nrp_id" => "Registrierte Spieler", 
    "SELECT COUNT(*) AS players_over_5 FROM level WHERE level > 5" => "Spieler über Level 5",
    "SELECT MAX(level) AS highest_level FROM level" => "Höchstes Level"
];

foreach ($queries as $query => $label) {
    $result = $conn->query($query);
    if ($result) {
        $row = $result->fetch_assoc();
        $stats[$label] = reset($row);
    } else {
        $stats[$label] = "Fehler bei der Abfrage";
    }
}

$conn->close();
?>

<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Serverstatistik</title>
    <link rel="stylesheet" href="stats.css">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
        function updateStats() {
            $.ajax({
                url: 'get_stats.php',
                method: 'GET',
                success: function(data) {
                    $('#online_log').text(data['Permanent gebannte Spieler']);
                    $('#post_log').text(data['Registrierte Spieler']);
                    $('#perma_log').text(data['Gebannte Spieler (AllTime)']);
                    $('#chat_log').text(data['Anzahl der Commands']);
                    $('#chat_messages').text(data['Anzahl der Chatnachrichten']);
                    $('#placed_blocks').text(data['Bereits platzierte Blöcke']);
                    $('#broken_blocks').text(data['Bereits abgebaute Blöcke']);
                    $('#players_lvl_5').text(data['Spieler über Level 5']);
                    $('#highest_level').text(data['Höchstes Level']);
                    $('#achievements').text(data['Erreichte Achievements']);
                },
                error: function() {
                    alert('Fehler beim Laden der Statistiken.');
                }
            });
        }

        setInterval(updateStats, 10000);
        $(document).ready(function() {
            updateStats(); 
        });
    </script>
</head>
<body>
    <a href="#" class="back-button">Back</a>
    <div class="container">
        <h1>Server-Statistiken</h1>
        <div class="stats">
            <div class="stat-item">
                <h2>Permanent gebannte Spieler</h2>
                <p id="online_log"><?php echo $stats["Permanent gebannte Spieler"]; ?></p>
            </div>
            <div class="stat-item">
                <h2>Registrierte Spieler</h2>
                <p id="post_log"><?php echo $stats["Registrierte Spieler"]; ?></p>
            </div>
            <div class="stat-item">
                <h2>Gebannte Spieler (AllTime)</h2>
                <p id="perma_log"><?php echo $stats["Gebannte Spieler (AllTime)"]; ?></p>
            </div>
            <div class="stat-item">
                <h2>Anzahl der Commands</h2>
                <p id="chat_log"><?php echo $stats["Anzahl der Commands"]; ?></p>
            </div>
            <div class="stat-item">
                <h2>Anzahl der Chatnachrichten</h2>
                <p id="chat_messages"><?php echo $stats["Anzahl der Chatnachrichten"]; ?></p>
            </div>
            <div class="stat-item">
                <h2>Bereits platzierte Blöcke</h2>
                <p id="placed_blocks"><?php echo $stats["Bereits platzierte Blöcke"]; ?></p>
            </div>
            <div class="stat-item">
                <h2>Bereits abgebaute Blöcke</h2>
                <p id="broken_blocks"><?php echo $stats["Bereits abgebaute Blöcke"]; ?></p>
            </div>
            <div class="stat-item">
                <h2>Spieler über Level 5</h2>
                <p id="players_lvl_5"><?php echo $stats["Spieler über Level 5"]; ?></p>
            </div>
            <div class="stat-item">
                <h2>Höchstes Level</h2>
                <p id="highest_level"><?php echo $stats["Höchstes Level"]; ?></p>
            </div>
            <div class="stat-item">
                <h2>Erreichte Achievements</h2>
                <p id="achievements"><?php echo $stats["Erreichte Achievements"]; ?></p>
            </div>
        </div>
    </div>
</body>
</html>
